@@ -12,14 +12,14 @@ RSpec.describe UniformNotifier::HoneybadgerNotifier do
   end
 
   it 'should notify honeybadger' do
-    expect(Honeybadger).to receive(:notify).with(UniformNotifier::Exception.new('notify honeybadger'), {})
+    expect(Honeybadger).to receive(:notify).with(UniformNotifier::Exception.new('notify honeybadger'))
 
     UniformNotifier.honeybadger = true
     UniformNotifier::HoneybadgerNotifier.out_of_channel_notify(title: 'notify honeybadger')
   end
 
   it 'should notify honeybadger' do
-    expect(Honeybadger).to receive(:notify).with(UniformNotifier::Exception.new('notify honeybadger'), { foo: :bar })
+    expect(Honeybadger).to receive(:notify).with(UniformNotifier::Exception.new('notify honeybadger'), foo: :bar)
 
     UniformNotifier.honeybadger = { foo: :bar }
     UniformNotifier::HoneybadgerNotifier.out_of_channel_notify('notify honeybadger')
